"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RepoCacheBase = void 0;
const tslib_1 = require("tslib");
const util_1 = require("util");
const zlib_1 = tslib_1.__importDefault(require("zlib"));
const hasha_1 = tslib_1.__importDefault(require("hasha"));
const global_1 = require("../../../../config/global");
const logger_1 = require("../../../../logger");
const common_1 = require("../common");
const compress = (0, util_1.promisify)(zlib_1.default.brotliCompress);
const decompress = (0, util_1.promisify)(zlib_1.default.brotliDecompress);
class RepoCacheBase {
    constructor(repository) {
        this.repository = repository;
        this.platform = global_1.GlobalConfig.get('platform');
        this.oldHash = null;
        this.data = {};
    }
    async load() {
        try {
            const oldCache = await this.read();
            if ((0, common_1.isValidRev12)(oldCache, this.repository)) {
                const compressed = Buffer.from(oldCache.payload, 'base64');
                const uncompressed = await decompress(compressed);
                const jsonStr = uncompressed.toString('utf8');
                this.data = JSON.parse(jsonStr);
                this.oldHash = oldCache.hash;
                logger_1.logger.debug('Repository cache is valid');
                return;
            }
            if ((0, common_1.isValidRev11)(oldCache, this.repository)) {
                this.data = oldCache.data;
                logger_1.logger.debug('Repository cache is migrated from 11 revision');
                return;
            }
            if ((0, common_1.isValidRev10)(oldCache, this.repository)) {
                delete oldCache.repository;
                delete oldCache.revision;
                this.data = oldCache;
                logger_1.logger.debug('Repository cache is migrated from 10 revision');
                return;
            }
            logger_1.logger.debug('Repository cache is invalid');
        }
        catch (err) {
            logger_1.logger.debug('Error reading repository cache');
        }
    }
    async save() {
        const revision = common_1.CACHE_REVISION;
        const repository = this.repository;
        const jsonStr = JSON.stringify(this.data);
        const hash = await hasha_1.default.async(jsonStr, { algorithm: 'sha256' });
        if (hash !== this.oldHash) {
            const compressed = await compress(jsonStr);
            const payload = compressed.toString('base64');
            await this.write({ revision, repository, payload, hash });
        }
    }
    getData() {
        return this.data;
    }
}
exports.RepoCacheBase = RepoCacheBase;
//# sourceMappingURL=base.js.map